@@ -38,4 +38,10 @@ impl From<FromUtf8Error> for Error {
             error: format!("{:?}", e)
         }
     }
+}
+
+impl ToString for Error {
+    fn to_string(&self) -> String {
+        self.error.clone()
+    }
 }
\ No newline at end of file
