@@ -1,8 +1,5 @@
-#[macro_use]
-extern crate wasm_bindgen;
-
 #[macro_use]
 extern crate lazy_static;
 
 pub mod membrane;
-mod error;
\ No newline at end of file
+pub mod error;
\ No newline at end of file
